@@ -19,6 +19,6 @@
 
 LIBDIR = r'/usr/local/lib'
 DATADIR = r'/usr/local/share'
-BUILDDIR = r'/usr/obj/ports/gst-devtools-1.28.0/build-amd64'
-SRCDIR = r'/usr/obj/ports/gst-devtools-1.28.0/gst-devtools-1.28.0'
+BUILDDIR = r'/pobj/gst-devtools-1.28.1/build-i386'
+SRCDIR = r'/pobj/gst-devtools-1.28.1/gst-devtools-1.28.1'
 GST_VALIDATE_TESTSUITE_VERSION = '1.28'
